@@ -129,9 +129,6 @@ enum
 };
 
 
-static void xfce_desktop_class_init(XfceDesktopClass *klass);
-
-static void xfce_desktop_init(XfceDesktop *desktop);
 static void xfce_desktop_finalize(GObject *object);
 static void xfce_desktop_set_property(GObject *object,
                                       guint property_id,
@@ -214,8 +211,14 @@ xfce_desktop_setup_icon_view(XfceDesktop *desktop)
         case XFCE_DESKTOP_ICON_STYLE_FILES:
             {
                 ThunarVfsPath *path;
-                gchar *desktop_path = xfce_get_homefile("Desktop",
-                                                        NULL);
+                gchar *desktop_path;
+                
+#if GLIB_CHECK_VERSION(2, 14, 0)
+                /* glib always returns non-NULL for _DESKTOP */
+                desktop_path = g_strdup(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP));
+#else
+                desktop_path = xfce_get_homefile("Desktop", NULL);
+#endif
 
                 path = thunar_vfs_path_new(desktop_path, NULL);
                 if(path) {
@@ -319,7 +322,8 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
     GdkScreen *gscreen = desktop->priv->gscreen;
     GdkPixbuf *pix;
     GdkRectangle rect;
-    gint i, monitor = -1;
+    guint i;
+    gint monitor = -1;
     
     TRACE("entering");
     
@@ -398,7 +402,7 @@ screen_size_changed_cb(GdkScreen *gscreen, gpointer user_data)
         backdrop_changed_cb(desktop->priv->backdrops[0], desktop);
     } else {
         GdkRectangle rect;
-        gint i;
+        guint i;
 
         for(i = 0; i < desktop->priv->nbackdrops; i++) {
             gdk_screen_get_monitor_geometry(gscreen, i, &rect);
@@ -414,7 +418,7 @@ xfce_desktop_monitors_changed(GdkScreen *gscreen,
                               gpointer user_data)
 {
     XfceDesktop *desktop = XFCE_DESKTOP(user_data);
-    gint i;
+    guint i;
 
     if(desktop->priv->xinerama_stretch) {
         if(desktop->priv->nbackdrops > 1) {
@@ -438,7 +442,7 @@ xfce_desktop_monitors_changed(GdkScreen *gscreen,
             desktop->priv->nbackdrops = 1;
         }
     } else {
-        gint n_monitors = gdk_screen_get_n_monitors(gscreen);
+        guint n_monitors = gdk_screen_get_n_monitors(gscreen);
 
         if(n_monitors < desktop->priv->nbackdrops) {
             for(i = n_monitors; i < desktop->priv->nbackdrops; ++i)
@@ -579,7 +583,7 @@ xfce_desktop_class_init(XfceDesktopClass *klass)
 #ifdef ENABLE_FILE_ICONS
                                                       XFCE_DESKTOP_ICON_STYLE_FILES,
 #else
-                                                      XFCE_DESKTOP_ICON_STLYE_WINDOWS,
+                                                      XFCE_DESKTOP_ICON_STYLE_WINDOWS,
 #endif
                                                       XFDESKTOP_PARAM_FLAGS));
 
@@ -736,8 +740,6 @@ xfce_desktop_realize(GtkWidget *widget)
     GTK_WIDGET_CLASS(xfce_desktop_parent_class)->realize(widget);
     
     gtk_window_set_title(GTK_WINDOW(desktop), _("Desktop"));
-    if(GTK_WIDGET_DOUBLE_BUFFERED(GTK_WIDGET(desktop)))
-        gtk_widget_set_double_buffered(GTK_WIDGET(desktop), FALSE);
     
     gtk_widget_set_size_request(GTK_WIDGET(desktop), sw, sh);
     gtk_window_move(GTK_WINDOW(desktop), 0, 0);
@@ -784,7 +786,7 @@ static void
 xfce_desktop_unrealize(GtkWidget *widget)
 {
     XfceDesktop *desktop = XFCE_DESKTOP(widget);
-    gint i;
+    guint i;
     GdkWindow *groot;
     gchar property_name[128];
     
@@ -893,7 +895,7 @@ xfce_desktop_expose(GtkWidget *w,
     XfceDesktop *desktop;
     GList *children, *l;
     
-    TRACE("entering");
+    /*TRACE("entering");*/
     
     if(evt->count != 0)
         return FALSE;
@@ -991,7 +993,10 @@ xfce_desktop_image_filename_changed(XfconfChannel *channel,
         return;
     backdrop = desktop->priv->backdrops[monitor];
 
-    filename = g_value_get_string(value);
+    if(!G_VALUE_HOLDS_STRING(value))
+        filename = DEFAULT_BACKDROP;
+    else
+        filename = g_value_get_string(value);
     if(G_LIKELY(filename && *filename)) {
         if(xfdesktop_backdrop_list_is_valid(filename)) {
             gchar *backdrop_file;
